Django Music Publisher
++++++++++++++++++++++

.. image:: https://travis-ci.com/matijakolaric-com/django-music-publisher.svg?branch=18.11
    :target: https://travis-ci.com/matijakolaric-com/django-music-publisher?branch=18.11
    :alt: Build Status
.. image:: https://coveralls.io/repos/github/matijakolaric-com/django-music-publisher/badge.svg?branch=18.11
    :target: https://coveralls.io/github/matijakolaric-com/django-music-publisher?branch=18.11
    :alt: Coverage Status
.. image:: https://img.shields.io/github/license/matijakolaric-com/django-music-publisher.svg
    :target: https://github.com/matijakolaric-com/django-music-publisher/blob/master/LICENSE
    :alt: License

Django Music Publisher is an open source software for original music publishers.

Please note that this is the **18.11 version**. This version is the last one still using 
an external metadata validation, CWR generation and CWR syntax highlighting service.
See https://matijakolaric.com/development/cwr-toolset/.

Newer versions validate the metadata and create CWR internally, while CWR syntax
highlighting is not available as open source.


* Docs: https://django-music-publisher.readthedocs.io/en/latest/
* Code: https://github.com/matijakolaric-com/django-music-publisher/
* PYPI: https://pypi.org/project/django-music-publisher/
